@@ -128,6 +128,8 @@ def get_object_descriptors(
     """
     Return list of ::class::`ObjectDescriptor` instances for all objects in memory
     after a call to gc.collect.
+
+    WARNING: Logging in this thread can cause a race condition if gevent is enabled
     """
 
     if ignored:
@@ -144,7 +146,6 @@ def get_object_descriptors(
     objs: List[object] = gc.get_objects()
 
     objs = [obj for obj in objs if _should_include_object(obj, ignore_set)]
-    ignore_set.add(id(objs))
     results = [get_data(obj) for obj in objs]
     del objs
     del ignore_set
